==> wasmedge_0.13.5+dfsg.orig.tar.xz: wasmedge/docs/CODE_OF_CONDUCT.md <==
# Code of Conduct

As a CNCF project, WasmEdge follows the [CNCF Code of Conduct](https://github.com/cncf/foundation/blob/master/code-of-conduct.md). In addition to this code of conduct, we have also implemented guidelines for the use of other developers' open-source work in your code.

Instances of abusive, harassing, or otherwise unacceptable behavior may be reported by contacting the WasmEdge team via <WasmEdge@googlegroups.com>.

As contributors and maintainers of this project, and in the interest of fostering an open and welcoming community, we pledge to respect all people who contribute through reporting issues, posting feature requests, updating documentation, submitting pull requests or patches, and other activities.

We are committed to making participation in this project a harassment-free experience for everyone, regardless of level of experience, gender, gender identity and expression, sexual orientation, disability, personal appearance, body size, race, ethnicity, age, religion, or nationality.

Examples of unacceptable behavior by participants include:

* The use of sexualized language or imagery
* Personal attacks
* Trolling or insulting/derogatory comments
* Public or private harassment
* Publishing others' private information, such as physical or electronic addresses, without explicit permission
* Other unethical or unprofessional conduct.

Project maintainers have the right and responsibility to remove, edit, or reject comments, commits, code, wiki edits, issues, and other contributions that are not aligned to this Code of Conduct. By adopting this Code of Conduct, project maintainers commit themselves to fairly and consistently applying these principles to every aspect of managing this project. Project maintainers who do not follow or enforce the Code of Conduct may be permanently removed from the project team.

This code of conduct applies both within project spaces and in public spaces when an individual is representing the project or its community.

In addition to the CNCF code of conduct, we would like to introduce a new code of conduct that demonstrates respect for open-source contributors. If you plan to use other developers' open-source work in your code, please make sure that the license of the original repository allows this. For instance, the Apache 2.0 license allows for free use of the code, provided that authors receive proper credit for their contributions. In order to appropriately recognize and acknowledge others' work, we kindly request that you add the following messages before you raise a PR or show your work in public:

1. At the top of any files you use, please include: "This file is licensed under Apache 2.0 and was originally developed by [the author name]."

2. Include a statement in the README like "This work was made possible by [the author name]."

See a best practice [here](https://github.com/WasmEdge/mediapipe-rs/pull/1#issuecomment-1580763759).

==> wasmedge_0.14.1+dfsg.orig.tar.xz: wasmedge/docs/CODE_OF_CONDUCT.md <==
# Code of Conduct

As a CNCF project, WasmEdge follows the [CNCF Code of Conduct](https://github.com/cncf/foundation/blob/master/code-of-conduct.md). In addition to this code of conduct, we have also implemented guidelines for the use of other developers' open-source work in your code.

Instances of abusive, harassing, or otherwise unacceptable behavior may be reported by contacting the WasmEdge team via <WasmEdge@googlegroups.com> or the private maintainer mailing list <cncf-wasmedge-runtime-maintainers@lists.cncf.io>.

As contributors and maintainers of this project, and in the interest of fostering an open and welcoming community, we pledge to respect all people who contribute through reporting issues, posting feature requests, updating documentation, submitting pull requests or patches, and other activities.

We are committed to making participation in this project a harassment-free experience for everyone, regardless of level of experience, gender, gender identity and expression, sexual orientation, disability, personal appearance, body size, race, ethnicity, age, religion, or nationality.

Examples of unacceptable behavior by participants include:

* The use of sexualized language or imagery
* Personal attacks
* Trolling or insulting/derogatory comments
* Public or private harassment
* Publishing others' private information, such as physical or electronic addresses, without explicit permission
* Other unethical or unprofessional conduct.

Project maintainers have the right and responsibility to remove, edit, or reject comments, commits, code, wiki edits, issues, and other contributions that are not aligned to this Code of Conduct. By adopting this Code of Conduct, project maintainers commit themselves to fairly and consistently applying these principles to every aspect of managing this project. Project maintainers who do not follow or enforce the Code of Conduct may be permanently removed from the project team.

This code of conduct applies both within project spaces and in public spaces when an individual is representing the project or its community.

In addition to the CNCF code of conduct, we would like to introduce a new code of conduct that demonstrates respect for open-source contributors. If you plan to use other developers' open-source work in your code, please make sure that the license of the original repository allows this. For instance, the Apache 2.0 license allows for free use of the code, provided that authors receive proper credit for their contributions. In order to appropriately recognize and acknowledge others' work, we kindly request that you add the following messages before you raise a PR or show your work in public:

1. At the top of any files you use, please include: "This file is licensed under Apache 2.0 and was originally developed by [the author name]."

2. Include a statement in the README like "This work was made possible by [the author name]."

See a best practice [here](https://github.com/WasmEdge/mediapipe-rs/pull/1#issuecomment-1580763759).
